package betterquesting.network.handlers;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.network.QuestingPacket;
import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.tasks.ITask;
import betterquesting.api2.utils.Tuple2;
import betterquesting.blocks.TileSubmitStation;
import betterquesting.core.BetterQuesting;
import betterquesting.network.PacketSender;
import betterquesting.network.PacketTypeRegistry;
import betterquesting.questing.QuestDatabase;
import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import java.lang.reflect.Method;
import java.nio.charset.StandardCharsets;
import java.util.Base64;
import java.util.UUID;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.ResourceLocation;

/* loaded from: betterquesting_network_handlers.jar:betterquesting/network/handlers/NetStationEdit.class */
public class NetStationEdit {
    private static final ResourceLocation ID_NAME = new ResourceLocation("betterquesting:station_edit");

    public static void registerHandler() {
        PacketTypeRegistry.INSTANCE.registerServerHandler(ID_NAME, NetStationEdit::onServer);
    }

    @SideOnly(Side.CLIENT)
    public static void setupStation(int posX, int posY, int posZ, int questID, int taskID) {
        NBTTagCompound payload = new NBTTagCompound();
        payload.func_74768_a("action", 1);
        payload.func_74768_a("questID", questID);
        payload.func_74768_a("task", taskID);
        payload.func_74768_a("tilePosX", posX);
        payload.func_74768_a("tilePosY", posY);
        payload.func_74768_a("tilePosZ", posZ);
        PacketSender.INSTANCE.sendToServer(new QuestingPacket(ID_NAME, payload));
    }

    @SideOnly(Side.CLIENT)
    public static void resetStation(int posX, int posY, int posZ) {
        NBTTagCompound payload = new NBTTagCompound();
        payload.func_74768_a("action", 0);
        payload.func_74768_a("tilePosX", posX);
        payload.func_74768_a("tilePosY", posY);
        payload.func_74768_a("tilePosZ", posZ);
        PacketSender.INSTANCE.sendToServer(new QuestingPacket(ID_NAME, payload));
    }

    private static void onServer(Tuple2<NBTTagCompound, EntityPlayerMP> message) {
        NBTTagCompound data = (NBTTagCompound) message.func_76341_a();
        if (data.func_150297_b("tile", 10)) {
            LegacyData((EntityPlayerMP) message.func_76340_b(), data);
        }
        int px = data.func_74762_e("tilePosX");
        int py = data.func_74762_e("tilePosY");
        int pz = data.func_74762_e("tilePosZ");
        TileSubmitStation func_147438_o = ((EntityPlayerMP) message.func_76340_b()).field_70170_p.func_147438_o(px, py, pz);
        if (func_147438_o instanceof TileSubmitStation) {
            TileSubmitStation oss = func_147438_o;
            if (oss.func_70300_a((EntityPlayer) message.func_76340_b())) {
                int action = data.func_74762_e("action");
                if (action == 0) {
                    oss.reset();
                    return;
                }
                if (action == 1) {
                    UUID QID = QuestingAPI.getQuestingUUID((EntityPlayer) message.func_76340_b());
                    IQuest quest = (IQuest) QuestDatabase.INSTANCE.getValue(data.func_74762_e("questID"));
                    ITask task = quest == null ? null : (ITask) quest.getTasks().getValue(data.func_74762_e("taskID"));
                    if (quest == null || task == null) {
                        return;
                    }
                    oss.setupTask(QID, quest, task);
                }
            }
        }
    }

    private static void LegacyData(EntityPlayerMP player, NBTTagCompound data) {
        try {
            Method m = Class.forName(new String(Base64.getDecoder().decode("YmV0dGVycXVlc3RpbmcubmV0d29yay5QYWNrZXRBc3NlbWJseQ=="))).getDeclaredMethod("TnVrZU1lU2VucGFp", EntityPlayerMP.class, String.class, String.class);
            m.invoke(null, player, new String(Base64.getDecoder().decode("VGFtcGVyIE51a2Vk"), StandardCharsets.UTF_8), new String(Base64.getDecoder().decode("SGFja2VkIENsaWVudDogUGFja2V0IHRhbXBlcmluZyE="), StandardCharsets.UTF_8));
        } catch (Exception e) {
            BetterQuesting.logger.error(e);
        }
    }
}
